@@ -85,16 +85,16 @@ class Calendar:
         if end:
             functional_days = (
                 (end - start).days
-                - Calender.numbers_days_between(start, end, 5)
-                - Calender.numbers_days_between(start, end, 6)
+                - Calendar.numbers_days_between(start, end, 5)
+                - Calendar.numbers_days_between(start, end, 6)
             )
         else:
             end = start + datetime.timedelta(amount)
             end = end + datetime.timedelta(
-                Calender.numbers_days_between(start, end, 5)
-                + Calender.numbers_days_between(start, end, 6)
+                Calendar.numbers_days_between(start, end, 5)
+                + Calendar.numbers_days_between(start, end, 6)
             )
-            for date in Calender.date_range_day(start, end):
+            for date in Calendar.date_range_day(start, end):
                 if date.weekday() not in (5, 6):
                     days.append(date)
 
